@@ -8,9 +8,9 @@ use Exporter 'import';
 use Perinci::Sub::Gen::AccessTable qw(gen_read_table_func);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-17'; # DATE
+our $DATE = '2022-12-28'; # DATE
 our $DIST = 'Ubuntu-Releases'; # DIST
-our $VERSION = '20221017.0'; # VERSION
+our $VERSION = '20221228.0'; # VERSION
 
 our @EXPORT_OK = qw(
                        list_ubuntu_releases
@@ -684,7 +684,7 @@ our $data = do {
      bash_version         => 5.1,
      code_name            => "jammy",
      eoldate              => "2027-04",
-     linux_version        => "5.15.0",
+     linux_version        => 5.15,
      mariadb_version      => "--",
      mysql_version        => "--",
      nginx_version        => undef,
@@ -696,6 +696,24 @@ our $data = do {
      ruby_version         => undef,
      version              => 22.04,
    },
+   {
+     animal               => "kudu",
+     apache_httpd_version => "--",
+     bash_version         => 5.2,
+     code_name            => "kinetic",
+     eoldate              => "2023-07",
+     linux_version        => 5.19,
+     mariadb_version      => "--",
+     mysql_version        => "--",
+     nginx_version        => undef,
+     perl_version         => "5.34.0",
+     php_version          => "--",
+     postgresql_version   => "--",
+     python_version       => "3.10.6",
+     reldate              => "2022-10-20",
+     ruby_version         => undef,
+     version              => "22.10",
+   },
  ]
 };
 
@@ -722,7 +740,7 @@ Ubuntu::Releases - List Ubuntu releases
 
 =head1 VERSION
 
-This document describes version 20221017.0 of Ubuntu::Releases (from Perl distribution Ubuntu-Releases), released on 2022-10-17.
+This document describes version 20221228.0 of Ubuntu::Releases (from Perl distribution Ubuntu-Releases), released on 2022-12-28.
 
 =head1 SYNOPSIS
 
@@ -1335,10 +1353,23 @@ Only return records where the 'python_version' field is less than specified valu
 
 Only return records where the 'python_version' field is greater than specified value.
 
-=item * B<query> => I<str>
+=item * B<queries> => I<array[str]>
 
 Search.
 
+This will search all searchable fields with one or more specified queries. Each
+query can be in the form of C<-FOO> (dash prefix notation) to require that the
+fields do not contain specified string, or C</FOO/> to use regular expression.
+All queries must match if the C<query_boolean> option is set to C<and>; only one
+query should match if the C<query_boolean> option is set to C<or>.
+
+=item * B<query_boolean> => I<str> (default: "and")
+
+Whether records must match all search queries ('and') or just one ('or').
+
+If set to C<and>, all queries must match; if set to C<or>, only one query should
+match. See the C<queries> option for more details on searching.
+
 =item * B<random> => I<bool> (default: 0)
 
 Return records in random order.
